pub(crate) fn ensure_fork_network_supported(
chain_id: u64,
) -> Result<(), BlockchainError>Expand description
Ensures Anvil’s EVM backend can execute the resolved upstream source chain.
Anvil’s execution chain-ID override does not change the bytecode format in remote fork state.