pub(crate) fn ensure_fork_network_supported(
chain_id: u64,
) -> Result<(), BlockchainError>Expand description
Ensures the fork network can be executed by Anvil’s EVM backend.
pub(crate) fn ensure_fork_network_supported(
chain_id: u64,
) -> Result<(), BlockchainError>Ensures the fork network can be executed by Anvil’s EVM backend.